@@ -25,6 +25,7 @@
 #include "panel/dzl-dock-widget.h"
 #include "panel/dzl-tab.h"
 #include "panel/dzl-tab-strip.h"
+#include "util/dzl-gtk.h"
 #include "util/dzl-macros.h"
 
 typedef struct
@@ -363,7 +364,6 @@ dzl_tab_strip_child_icon_name_changed (DzlTabStrip *self,
                                        GParamSpec  *pspec,
                                        GtkWidget   *child)
 {
-  gchar *icon_name = NULL;
   GtkWidget *parent;
   DzlTab *tab;
 
@@ -379,13 +379,22 @@ dzl_tab_strip_child_icon_name_changed (DzlTabStrip *self,
 
   g_assert (GTK_IS_STACK (parent));
 
-  gtk_container_child_get (GTK_CONTAINER (parent), child,
-                           "icon-name", &icon_name,
-                           NULL);
+  if (DZL_IS_DOCK_ITEM (child))
+    {
+      g_autoptr(GIcon) gicon = NULL;
 
-  dzl_tab_set_icon_name (tab, icon_name);
+      gicon = dzl_dock_item_ref_gicon (DZL_DOCK_ITEM (child));
+      dzl_tab_set_gicon (tab, gicon);
+    }
+  else
+    {
+      g_autofree gchar *icon_name = NULL;
 
-  g_free (icon_name);
+      gtk_container_child_get (GTK_CONTAINER (parent), child,
+                               "icon-name", &icon_name,
+                               NULL);
+      dzl_tab_set_icon_name (tab, icon_name);
+    }
 }
 
 static void
@@ -425,6 +434,42 @@ dzl_tab_strip_tab_clicked (DzlTabStrip *self,
     }
 }
 
+static void
+dzl_tab_strip_gicon_changed (DzlDockItem *item,
+                             GParamSpec  *pspec,
+                             DzlTab      *tab)
+{
+  g_autoptr(GIcon) icon = NULL;
+
+  g_assert (DZL_IS_DOCK_ITEM (item));
+  g_assert (DZL_IS_TAB (tab));
+
+  if ((icon = dzl_dock_item_ref_gicon (item)))
+    dzl_tab_set_gicon (tab, icon);
+}
+
+static void
+dzl_tab_strip_child_needs_attention (DzlTab     *tab,
+                                     GParamSpec *pspec,
+                                     GtkWidget  *child)
+{
+  GtkWidget *parent;
+  gboolean needs_attention;
+
+  g_assert (DZL_IS_TAB (tab));
+  g_assert (GTK_IS_WIDGET (child));
+
+  parent = gtk_widget_get_parent (child);
+  gtk_container_child_get (GTK_CONTAINER (parent), child,
+                           "needs-attention", &needs_attention,
+                           NULL);
+
+  if (needs_attention)
+    dzl_gtk_widget_add_style_class (GTK_WIDGET (tab), "needs-attention");
+  else
+    dzl_gtk_widget_remove_style_class (GTK_WIDGET (tab), "needs-attention");
+}
+
 static void
 dzl_tab_strip_stack_add (DzlTabStrip *self,
                          GtkWidget   *widget,
@@ -432,8 +477,9 @@ dzl_tab_strip_stack_add (DzlTabStrip *self,
 {
   DzlTabStripPrivate *priv = dzl_tab_strip_get_instance_private (self);
   g_autoptr(GVariant) target = g_variant_ref_sink (g_variant_new_int32 (0));
-  DzlTab *tab;
+  gboolean needs_attention = FALSE;
   gboolean can_close = FALSE;
+  DzlTab *tab;
 
   g_assert (DZL_IS_TAB_STRIP (self));
   g_assert (GTK_IS_WIDGET (widget));
@@ -453,12 +499,25 @@ dzl_tab_strip_stack_add (DzlTabStrip *self,
 
   g_object_set_data (G_OBJECT (widget), "DZL_TAB", tab);
 
+  gtk_container_child_get (GTK_CONTAINER (stack), widget,
+                           "needs-attention", &needs_attention,
+                           NULL);
+
+  if (needs_attention)
+    dzl_gtk_widget_add_style_class (GTK_WIDGET (tab), "needs-attention");
+
   g_signal_connect_object (tab,
                            "clicked",
                            G_CALLBACK (dzl_tab_strip_tab_clicked),
                            self,
                            G_CONNECT_SWAPPED | G_CONNECT_AFTER);
 
+  g_signal_connect_object (widget,
+                           "child-notify::needs-attention",
+                           G_CALLBACK (dzl_tab_strip_child_needs_attention),
+                           tab,
+                           G_CONNECT_SWAPPED);
+
   g_signal_connect_object (widget,
                            "child-notify::position",
                            G_CALLBACK (dzl_tab_strip_child_position_changed),
@@ -477,6 +536,13 @@ dzl_tab_strip_stack_add (DzlTabStrip *self,
                            self,
                            G_CONNECT_SWAPPED);
 
+  if (DZL_IS_DOCK_ITEM (widget))
+    g_signal_connect_object (widget,
+                             "notify::gicon",
+                             G_CALLBACK (dzl_tab_strip_gicon_changed),
+                             tab,
+                             0);
+
   gtk_container_add_with_properties (GTK_CONTAINER (self), GTK_WIDGET (tab),
                                      "pack-type", GTK_PACK_START,
                                      "expand", TRUE,
@@ -489,7 +555,10 @@ dzl_tab_strip_stack_add (DzlTabStrip *self,
     g_object_bind_property (widget, "can-close", tab, "can-close", 0);
 
   dzl_tab_strip_child_title_changed (self, NULL, widget);
-  dzl_tab_strip_child_icon_name_changed (self, NULL, widget);
+  if (DZL_IS_DOCK_ITEM (widget))
+    dzl_tab_strip_gicon_changed (DZL_DOCK_ITEM (widget), NULL, tab);
+  else
+    dzl_tab_strip_child_icon_name_changed (self, NULL, widget);
   dzl_tab_strip_stack_notify_visible_child (self, NULL, stack);
 }
 
